/***********************
** METADATA
***********************/

/****
Created by: George Borjas and Joan Monras
Date: December 2016
Purpose: Read Israeli Census Data

Inputs: Israeli_raw_Census.dta

Outputs: Graphs and regressions on the Israeli episode

****/


/***********************
** COMPUTING RESOURCES
***********************/

clear all
set more off
cd ~
if (regexm("`c(pwd)'","/home/joan")==1) {
 global dropbox "/home/joan/Dropbox/Sciences Po/refugees_and_labor_market_borjas_monras" //Joan's Ubuntu laptop
}		

/***********************
** PROGRAMS
***********************/


cap program drop sumstat_dependent //This program aggregates the data to the appropriate cell
program define sumstat_dependent

tempfile t1 t2

syntax using/,  [agemin(integer 1) agemax(integer 1)  sex(string) age(string) education(string)]  

use "`using'", clear

keep if year==1995 | year==1983

** age selection

keep if age>=`agemin' & age<=`agemax'

** Drop females if sex==1

if ("`sex'"=="1") {
drop if sex==2
}


** Drop observations without occupation or industry information if occupation or industry cells
generate oldocc=occ
replace occ=0 if occ==1 & year<1995
replace occ=1 if occ==2 & year<1995
replace occ=2 if occ==3 & year<1995
replace occ=3 if occ==4 & year<1995
replace occ=4 if (occ==5 | occ==6) & year<1995
replace occ=5 if occ==7 & year<1995
replace occ=6 if occ==8 & year<1995
replace occ=7 if occ==9 & year<1995
drop if occ==98 | occ==99 //Non-employed workers in the 1985 sample have no occupation 


gen soviet_stock=0
replace soviet_stock=1 if bplcountry==34010 | bplcountry==34020 | bplcountry==41010 | bplcountry==42020 | ///
		    bplcountry==34050 | bplcountry==32060 | bplcountry==32070 | bplcountry== 42070 | ///
		    bplcountry==42080 | bplcountry==41060 | bplcountry==41080 | bplcountry==32120 | ///
		    bplcountry==32130 | bplcountry==32140 | bplcountry==41100 
gen soviet=0
replace soviet=1 if (bplcountry==34010 | bplcountry==34020 | bplcountry==41010 | bplcountry==42020 | ///
		    bplcountry==34050 | bplcountry==32060 | bplcountry==32070 | bplcountry== 42070 | ///
		    bplcountry==42080 | bplcountry==41060 | bplcountry==41080 | bplcountry==32120 | ///
		    bplcountry==32130 | bplcountry==32140 | bplcountry==41100) & (yrimm2==66 | yrimm2==72) 


generate native=(soviet_stock!=1)

gen active=(laboril==1)
gen inactive=(laboril==2)

generate native_active=(active==1 & native==1)
generate native_inactive=(inactive==1 & native==1)
generate hebrew_lang=(lang==1 & native==1)

** Selects the sample for the wages regressions. Drop not valid wage, keep salary worker, nonrussian, not in school and native 

replace incwage=. if incwage==9999999 | incwage==9999998 | incwage==0 | classwk!=2 | soviet==1 | school==1 
replace incwage=incwage/1000 if year==1983 // The old shekel moves to the new shekel
replace incwage=ln(incwage)

replace soviet_stock=soviet_stock*perwt
replace soviet=soviet*perwt
replace native=native*perwt 
replace hebrew_lang= hebrew_lang*perwt

generate byte agecode=1*(age>=25 & age<=34) + 2*(age>=35 & age<=44) + 3*(age>=45 & age<=54) + 4*(age>=55 & age<=59)

gen obs=1

drop if edattain==9 //Education attainment not known. Alternatively we can recode this as lowest level.

if ("`education'" == "aggregate") {
//drop if edattain==3
replace edattain=1 if edattain<=3
replace edattain=2 if edattain==4
}

gen high_immi=(occ==7)

collapse (rawsum) soviet soviet_stock native total=perwt native_active native_inactive hebrew_lang (count) nobs=native (mean) incwage [aw=perwt], by(year edattain `age' high)

reg incwage i.year
predict res_incwage, res
drop incwage
ren res_incwage incwage

drop if high==1

egen code=group(edattain  `age')
tsset code year, delta(12)


*THIS GIVES THE CHANGE IN UNEMP & EMP RATE OF NON-REPATRIATE FRENCH NATIVES

generate dwage2=incwage - L.incwage
generate derate2=(native_active/native) - (L.native_active/L.native)

tsset code year, delta(12)

gen nobs_tot=nobs+L.nobs
drop nobs
ren nobs nobs

drop if dwage2==. 

keep dwage2 edattain nobs year code
save `t1', replace

use "`using'", clear

keep if year==1995 | year==1983

** age selection

keep if age>=`agemin' & age<=`agemax'

** Drop females if sex==1

if ("`sex'"=="1") {
drop if sex==2
}


generate oldocc=occ
replace occ=0 if occ==1 & year<1995
replace occ=1 if occ==2 & year<1995
replace occ=2 if occ==3 & year<1995
replace occ=3 if occ==4 & year<1995
replace occ=4 if (occ==5 | occ==6) & year<1995
replace occ=5 if occ==7 & year<1995
replace occ=6 if occ==8 & year<1995
replace occ=7 if occ==9 & year<1995
drop if occ==98 | occ==99 //Non-employed workers in the 1985 sample have no occupation 


gen soviet_stock=0
replace soviet_stock=1 if bplcountry==34010 | bplcountry==34020 | bplcountry==41010 | bplcountry==42020 | ///
		    bplcountry==34050 | bplcountry==32060 | bplcountry==32070 | bplcountry== 42070 | ///
		    bplcountry==42080 | bplcountry==41060 | bplcountry==41080 | bplcountry==32120 | ///
		    bplcountry==32130 | bplcountry==32140 | bplcountry==41100 
gen soviet=0
replace soviet=1 if (bplcountry==34010 | bplcountry==34020 | bplcountry==41010 | bplcountry==42020 | ///
		    bplcountry==34050 | bplcountry==32060 | bplcountry==32070 | bplcountry== 42070 | ///
		    bplcountry==42080 | bplcountry==41060 | bplcountry==41080 | bplcountry==32120 | ///
		    bplcountry==32130 | bplcountry==32140 | bplcountry==41100) & (yrimm2==66 | yrimm2==72) 


generate native=(soviet_stock!=1)

gen active=(laboril==1)
gen inactive=(laboril==2)

generate native_active=(active==1 & native==1)
generate native_inactive=(inactive==1 & native==1)
generate hebrew_lang=(lang==1 & native==1)

** Selects the sample for the wages regressions. Drop not valid wage, keep salary worker, nonrussian, not in school and native 

replace incwage=. if incwage==9999999 | incwage==9999998 | incwage==0 | classwk!=2 | soviet==1 | school==1 
replace incwage=incwage/1000 if year==1983 // The old shekel moves to the new shekel
replace incwage=ln(incwage)

replace soviet_stock=soviet_stock*perwt
replace soviet=soviet*perwt
replace native=native*perwt 
replace hebrew_lang= hebrew_lang*perwt

generate byte agecode=1*(age>=25 & age<=34) + 2*(age>=35 & age<=44) + 3*(age>=45 & age<=54) + 4*(age>=55 & age<=59)

gen obs=1

drop if edattain==9 //Education attainment not known. Alternatively we can recode this as lowest level.

if ("`education'" == "aggregate") {
//drop if edattain==3
replace edattain=1 if edattain<=3
replace edattain=2 if edattain==4
}

gen high_immi=(occ==7)

collapse (rawsum) soviet soviet_stock native total=perwt native_active native_inactive hebrew_lang (count) nobs=native (mean) incwage [aw=perwt], by(year edattain `age' high)

reg incwage i.year
predict res_incwage, res
drop incwage
ren res_incwage incwage

drop if high==0

egen code=group(edattain  `age')
tsset code year, delta(12)


*THIS GIVES THE CHANGE IN UNEMP & EMP RATE OF NON-REPATRIATE FRENCH NATIVES

generate dwage2=incwage - L.incwage
generate derate2=(native_active/native) - (L.native_active/L.native)

tsset code year, delta(12)

gen nobs_tot=nobs+L.nobs
drop nobs
ren nobs nobs

drop if dwage2==. 

keep dwage2 edattain nobs year code
save `t2'

use `t1', clear
append using `t2'


gen order=_n
foreach var of varlist dwage2 { 
	generate `var'_str = string(`var',"%6.2f") 
	replace `var'_str = "" if `var'_str=="." 
}
	generate nobs_str = string(nobs,"%6.0f") 

gen edcode_string = "Less than primary" if edattain==1
replace edcode_string = "Primary completed" if edattain==2
replace edcode_string = "Secondary completed" if edattain==3
replace edcode_string = "University completed" if edattain==4

drop nobs dwage2 edattain


drop year code
set obs 10
replace order=order+1 if order>4
replace order=5 in 9
replace edcode_string ="\textbf{Skilled workers in industry, construction and other skilled workers:}" in 9
replace order=0 in 10
replace edcode_string ="\textbf{Average in Israel (excl. Skilled workers in ind...):}" in 10
sort order
drop order

listtex edcode_string dwage2_str nobs_str  using "$dropbox/tables/sumstat_Israel_dependent.tex", replace ///
rstyle(tabular) head("\begin{tabular}{lcc} \hline" " & Change in (log) Wages & Sample size \\ \hline") foot("\hline \end{tabular}")

keep edcode_string dwage2_str nobs_str  
order edcode_string dwage2_str nobs_str  
export excel using "$dropbox/tables/sumstat_Israel_dependent.xls", replace

end

cap program drop aggregate_data //This program aggregates the data to the appropriate cell
program define aggregate_data

syntax using/,  geo(string) [agemin(integer 1) agemax(integer 1)  sex(string) age(string) education(string)]  

use "`using'", clear

keep if year==1995 | year==1983

** age selection

keep if age>=`agemin' & age<=`agemax'

** Drop females if sex==1

if ("`sex'"=="1") {
drop if sex==2
}


** Drop observations without occupation or industry information if occupation or industry cells
if ("`geo'"=="occ"){
**recode occupations. This part follows Borja's code
generate oldocc=occ
replace occ=0 if occ==1 & year<1995
replace occ=1 if occ==2 & year<1995
replace occ=2 if occ==3 & year<1995
replace occ=3 if occ==4 & year<1995
replace occ=4 if (occ==5 | occ==6) & year<1995
replace occ=5 if occ==7 & year<1995
replace occ=6 if occ==8 & year<1995
replace occ=7 if occ==9 & year<1995
drop if occ==98 | occ==99 //Non-employed workers in the 1985 sample have no occupation 
}
if ("`geo'"=="geo2") {
drop if geo2_ilx==.
}


gen soviet_stock=0
replace soviet_stock=1 if bplcountry==34010 | bplcountry==34020 | bplcountry==41010 | bplcountry==42020 | ///
		    bplcountry==34050 | bplcountry==32060 | bplcountry==32070 | bplcountry== 42070 | ///
		    bplcountry==42080 | bplcountry==41060 | bplcountry==41080 | bplcountry==32120 | ///
		    bplcountry==32130 | bplcountry==32140 | bplcountry==41100 
gen soviet=0
replace soviet=1 if (bplcountry==34010 | bplcountry==34020 | bplcountry==41010 | bplcountry==42020 | ///
		    bplcountry==34050 | bplcountry==32060 | bplcountry==32070 | bplcountry== 42070 | ///
		    bplcountry==42080 | bplcountry==41060 | bplcountry==41080 | bplcountry==32120 | ///
		    bplcountry==32130 | bplcountry==32140 | bplcountry==41100) & (yrimm2==66 | yrimm2==72) 


generate native=(soviet_stock!=1)

gen active=(laboril==1)
gen inactive=(laboril==2)

generate native_active=(active==1 & native==1)
generate native_inactive=(inactive==1 & native==1)
generate hebrew_lang=(lang==1 & native==1)

** Selects the sample for the wages regressions. Drop not valid wage, keep salary worker, nonrussian, not in school and native 

replace incwage=. if incwage==9999999 | incwage==9999998 | incwage==0 | classwk!=2 | soviet==1 | school==1 
replace incwage=incwage/1000 if year==1983 // The old shekel moves to the new shekel
replace incwage=ln(incwage)

replace soviet_stock=soviet_stock*perwt
replace soviet=soviet*perwt
replace native=native*perwt 
replace hebrew_lang= hebrew_lang*perwt

generate byte agecode=1*(age>=25 & age<=34) + 2*(age>=35 & age<=44) + 3*(age>=45 & age<=54) + 4*(age>=55 & age<=59)

gen obs=1

drop if edattain==9 //Education attainment not known. Alternatively we can recode this as lowest level.

if ("`education'" == "aggregate") {
//drop if edattain==3
replace edattain=1 if edattain<=3
replace edattain=2 if edattain==4
}



collapse (rawsum) soviet soviet_stock native total=perwt native_active native_inactive hebrew_lang (count) nobs=native (mean) incwage [aw=perwt], by(`geo' year edattain `age')

egen code=group(`geo'  edattain  `age')
tsset code year, delta(12)


*THIS GIVES THE CHANGE IN UNEMP & EMP RATE OF NON-REPATRIATE FRENCH NATIVES

generate dwage2=incwage - L.incwage
generate derate2=(native_active/native) - (L.native_active/L.native)


**************************
*BUT WHAT ABOUT THE OTHER GUEST WORKERS
*WE WILL NEED TO ADDRESS THIS ISSUE SOMEHOW
*FOR NOW I WILL IGNORE THEM
***************************

*WE WANT TO DEFINE THE SHOCKS IN TERMS OF THE CORRECT THEORETICAL SPECIFICATION

*IN TIME 0, EVERYONE IS A FRENCH NATIVE
*IN TIME 1, ONLY THE NON-ALGERIANS AND NON-REPATRIATES ARE "NATIVES"
*I WILL DEFINE THE NATIVE CHANGE IN TERMS OF POPULATION TO AVOID ENDOGENEITY
generate nat0=L.total
generate nat1=total-soviet
generate dnat=log(nat1/nat0)


*THE SUPPLY SHOCK IS # OF IMMIGRANTS DIVIDED BY "NATIVES" IN 1968
*DREP MEASURES THE NUBMER OF REPATRIATE IMMIGRANTS

generate dsoviet=soviet_stock-L.soviet_stock
generate soviet1=soviet/(total) //This is a change relative to the original code, some cells there are just too many soviets. 
//generate soviet1=soviet/(total-soviet) //Running the same we had before results in similar results but bad behavior of the first stage for occupations, because there are some occupations with *lots* of russian emigres.

bysort year edattain: egen soviet_ed_total=sum(soviet)
bysort year edattain: egen native_ed_total=sum(native)

bysort year `geo': egen soviet_`geo'_total=sum(soviet)
bysort year `geo': egen native_`geo'_total=sum(native)

tsset code year, delta(12)

gen distr_native_ed=native/native_ed_total
gen soviet1_hat1=(L.distr_native_ed*soviet_ed_total)/total // This computes the share of immigrants using natives occupation distribution within education groups

//gen soviet0_hat1=(L.distr_native_ed*soviet_ed_total)/L.total // This computes the share of immigrants using natives occupation distribution within education groups

gen distr_native_`geo'=native/native_`geo'_total
gen soviet1_hat2=(L.distr_native_`geo'*soviet_`geo'_total)/total // This computes the share of immigrants using natives education distribution within occupations

//gen soviet0_hat2=(L.distr_native_`geo'*soviet_`geo'_total)/L.total // This computes the share of immigrants using natives education distribution within occupations

generate soviet0=L.soviet_stock/L.total
generate hebrew_lang0=L.hebrew_lang/L.total


*NOBS IS THE NUMBER OF NATIVES, BOTH WORKING & NON-WORKING, IN CELL;
generate weight=(nobs*L.nobs)/(nobs+L.nobs)


*** Labeling variables

label var dwage2 "Change in (log) Wages"
label var derate2 "Change in Share Employed"

label var soviet0 "L. Share from Soviet Union"

label var soviet1 "Inflows from Soviet Union"
label var dnat "Change in cell size"

if ("`geo'"=="occ"){
label var soviet1_hat1 "Predicted inflows using native occ.-distr. by edu."
label var soviet1_hat2 "Predicted inflows using native edu.-distr. by occ."
}
else {
label var soviet1_hat1 "Predicted inflows using native geo-distr. by edu."
label var soviet1_hat2 "Predicted inflows using native edu.-distr. by geo."
}
label var hebrew_lang0 "Share of workers who speak Hebrew"

tsset code year, delta(12)


end


cap program drop regressions
program define regressions

syntax , [geo(string) tablenum(string) age(string) file_name(string)]

** UNEMPLOYMENT RATE

** GRAPHS

two (scatter dwage2 soviet1 [aw=weight] if edattain==1, msymbol(circle_hollow) msize(vsmall)) ///
    (scatter dwage2 soviet1 [aw=weight] if edattain==2, msymbol(circle_hollow) msize(vsmall)) ///
    (scatter dwage2 soviet1 [aw=weight] if edattain==3, msymbol(circle_hollow) msize(vsmall)) ///
    (scatter dwage2 soviet1 [aw=weight] if edattain==4, msymbol(circle_hollow) msize(vsmall)), graphregion(color(white)) legend(off)
graph export "$dropbox/figures/Israel_raw_graph_soviet_`tablenum'.png", replace

two (scatter dwage2 soviet1_hat1 [aw=weight] if edattain==1, msymbol(circle_hollow) msize(vsmall)) ///
    (scatter dwage2 soviet1_hat1 [aw=weight] if edattain==2, msymbol(circle_hollow) msize(vsmall)) ///
    (scatter dwage2 soviet1_hat1 [aw=weight] if edattain==3, msymbol(circle_hollow) msize(vsmall)) ///
    (scatter dwage2 soviet1_hat1 [aw=weight] if edattain==4, msymbol(circle_hollow) msize(vsmall)), graphregion(color(white)) legend(off)
graph export "$dropbox/figures/Israel_raw_graph_soviet_hat_`tablenum'.png", replace

two (scatter dwage2 soviet1_hat2 [aw=weight] if edattain==1, msymbol(circle_hollow) msize(vsmall)) ///
    (scatter dwage2 soviet1_hat2 [aw=weight] if edattain==2, msymbol(circle_hollow) msize(vsmall)) ///
    (scatter dwage2 soviet1_hat2 [aw=weight] if edattain==3, msymbol(circle_hollow) msize(vsmall)) ///
    (scatter dwage2 soviet1_hat2 [aw=weight] if edattain==4, msymbol(circle_hollow) msize(vsmall)), graphregion(color(white)) legend(off)
   
** WAGES

xi: areg soviet1 soviet0 `age' if year==1995 [aw=weight],robust a(edattain)
outreg2 using "$dropbox/tables/Israel1_`tablenum'.xls", replace tex(frag) noaster nor2 dec(3) fmt(f) nonotes drop(_I**)  label noobs nocons stats(coef se) ctitle("Inflows soviet.","OLS")
xi: areg soviet1 soviet0 dnat `age'    if year==1995 [aw=weight],robust a(edattain)
outreg2 using "$dropbox/tables/Israel1_`tablenum'.xls", tex(frag) noaster  nonotes nor2 dec(3) fmt(f) drop(_I**)  label noobs nocons stats(coef se) ctitle("Inflows soviet.","OLS")
xi: areg dwage2 soviet0 `age'    if year==1995 [aw=weight], robust a(edattain)
outreg2 using "$dropbox/tables/Israel1_`tablenum'.xls", tex(frag) noaster  nonotes nor2 dec(3) fmt(f) drop(_I**)  label noobs nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","OLS")
xi: areg dwage2 soviet0 dnat  `age'   if year==1995 [aw=weight], robust a(edattain)
outreg2 using "$dropbox/tables/Israel1_`tablenum'.xls", tex(frag) noaster  nonotes nor2 dec(3) fmt(f) drop(_I**)  label noobs nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","OLS")

xi: areg dwage2 soviet1  `age'   if year==1995 [aw=weight], robust a(edattain)
outreg2 using "$dropbox/tables/Israel2_`tablenum'.xls", tex(frag) noaster  nonotes nor2 dec(3) fmt(f) drop(_I**) replace label addtext("Education FE","yes"  ) nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","OLS")
xi: areg dwage2 soviet1 dnat  `age'   if year==1995 [aw=weight], robust a(edattain)
outreg2 using "$dropbox/tables/Israel2_`tablenum'.xls", tex(frag) noaster  nonotes nor2 dec(3) fmt(f) drop(_I**)  label addtext("Education FE","yes"  ) nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","OLS")
 
xi: ivreg2 dwage2 (soviet1 = soviet0) `age'    i.edattain if year==1995 [aw=weight], robust
outreg2 using "$dropbox/tables/Israel2_`tablenum'.xls", tex(frag) noaster  nonotes nor2 dec(3) fmt(f) drop(_I**)  label addtext("Education FE","yes"  ) nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","IV") e(widstat)
xi: ivreg2 dwage2 (soviet1 = soviet0) dnat `age'    i.edattain if year==1995 [aw=weight], robust
outreg2 using "$dropbox/tables/Israel2_`tablenum'.xls", tex(frag) noaster  nonotes nor2 dec(3) fmt(f) drop(_I**)  label addtext("Education FE","yes"  ) nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","IV") e(widstat)


** SHARE EMPLOYED


xi: areg derate2 soviet1  `age'   if year==1995 [aw=weight], robust a(edattain)
outreg2 using "$dropbox/tables/Israel4_`tablenum'.xls", tex(frag) noaster  nonotes nor2 dec(3) fmt(f) drop(_I**) replace label addtext("Education FE","yes"  ) nocons stats(coef se) ctitle("$\Delta$ Nat. Emplo.","OLS")
xi: areg derate2 soviet1 dnat  `age'   if year==1995 [aw=weight], robust a(edattain)
outreg2 using "$dropbox/tables/Israel4_`tablenum'.xls", tex(frag) noaster  nonotes nor2 dec(3) fmt(f) drop(_I**)  label addtext("Education FE","yes"  ) nocons stats(coef se) ctitle("$\Delta$ Nat. Emplo.","OLS")
xi: ivreg2 derate2 (soviet1 = soviet0)  `age'   i.edattain if year==1995 [aw=weight], robust
outreg2 using "$dropbox/tables/Israel4_`tablenum'.xls", tex(frag) noaster  nonotes nor2 dec(3) fmt(f) drop(_I**)  label addtext("Education FE","yes"  ) nocons stats(coef se) ctitle("$\Delta$ Nat. Emplo.","IV") e(widstat)
xi: ivreg2 derate2 (soviet1 = soviet0) dnat  `age'   i.edattain if year==1995 [aw=weight], robust
outreg2 using "$dropbox/tables/Israel4_`tablenum'.xls", tex(frag) noaster  nonotes nor2 dec(3) fmt(f) drop(_I**)  label addtext("Education FE","yes"  ) nocons stats(coef se) ctitle("$\Delta$ Nat. Emplo.","IV") e(widstat)



*** SKILL AND OCCUPATION DOWNGRADING

/*
xi: reg soviet1 soviet1_hat1 `age' i.edattain if year==1995 [aw=weight], robust
outreg2 using "$dropbox/tables/Israel5_`tablenum'.xls", replace tex(frag) noaster nor2 dec(3) fmt(f) nonotes drop(_I**)  label nocons stats(coef se) ctitle("Inflows soviet.","OLS")
xi: reg soviet1 soviet1_hat2 `age' i.edattain if year==1995 [aw=weight], robust
outreg2 using "$dropbox/tables/Israel5_`tablenum'.xls", tex(frag) noaster nor2 dec(3) fmt(f) nonotes drop(_I**)  label nocons stats(coef se) ctitle("Inflows soviet.","OLS")
xi: reg soviet1 hebrew_lang0 `age' i.edattain if year==1995 [aw=weight], robust
outreg2 using "$dropbox/tables/Israel5_`tablenum'.xls", tex(frag) noaster nor2 dec(3) fmt(f) nonotes drop(_I**)  label nocons stats(coef se) ctitle("Inflows soviet.","OLS")
*/

xi: reg dwage2 soviet1_hat1 `age' i.edattain if year==1995 [aw=weight], robust
outreg2 using "$dropbox/tables/Israel5_`tablenum'.xls", tex(frag) noaster replace nor2 dec(3) fmt(f) nonotes drop(_I**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","OLS")
xi: reg dwage2 soviet1_hat2 `age' i.edattain if year==1995 [aw=weight], robust
outreg2 using "$dropbox/tables/Israel5_`tablenum'.xls", tex(frag) noaster nor2 dec(3) fmt(f) nonotes drop(_I**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","OLS")
//xi: reg dwage2 hebrew_lang0 `age' i.edattain if year==1995 [aw=weight], robust
//outreg2 using "$dropbox/tables/Israel5_`tablenum'.xls", tex(frag) noaster nor2 dec(3) fmt(f) nonotes drop(_I**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","OLS")

xi: reg dwage2 soviet1_hat1 `age' dnat i.edattain if year==1995 [aw=weight], robust
outreg2 using "$dropbox/tables/Israel5_`tablenum'.xls", tex(frag) noaster nor2 dec(3) fmt(f) nonotes drop(_I**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","OLS")
xi: reg dwage2 soviet1_hat2 `age' dnat i.edattain if year==1995 [aw=weight], robust
outreg2 using "$dropbox/tables/Israel5_`tablenum'.xls", tex(frag) noaster nor2 dec(3) fmt(f) nonotes drop(_I**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","OLS")
//xi: reg dwage2 hebrew_lang0 `age' dnat i.edattain if year==1995 [aw=weight], robust
//outreg2 using "$dropbox/tables/Israel5_`tablenum'.xls", tex(frag) noaster nor2 dec(3) fmt(f) nonotes drop(_I**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","OLS")

drop _I**
export excel using "$dropbox/data/`file_name'.xls",  firstrow(variables) replace

end

cap program drop regressions_cross_effects
program define regressions_cross_effects

syntax , [geo(string) tablenum(string) age(string) education(string)]

if ("`education'"!="aggregate") {

** GENERATE INTERACTIONS

gen edcode1=(edattain==1)
gen edcode2=(edattain==2)
gen edcode3=(edattain==3)
gen edcode4=(edattain==4)

local varlist "soviet1 soviet0 soviet1_hat2"
foreach var of local varlist{
forvalues i=1(1)4 {
gen sign = abs(`var')/`var'
gen `var'_aux=`var'*edcode`i'
bysort `geo' year: egen `var'_edcode`i'=max(abs(`var'_aux))
replace `var'_edcode`i' = `var'_edcode`i' * sign if `var'!=0
drop `var'_aux sign
}
}
forvalues i=1(1)4 {
gen sign = abs(dnat)/dnat
gen dnat_aux=dnat*edcode`i'
bysort `geo' year: egen dnat_edcode`i'=max(abs(dnat_aux))
replace dnat_edcode`i' = sign * dnat_edcode`i'
drop dnat_aux sign
}
forvalues i=1(1)4 {
gen edcode`i'_soviet1_edcode1=edcode`i'*soviet1_edcode1
}


label var soviet1_edcode4 "Inflows from Soviet Union, most-skilled" 

xi: ivreg2 dwage2 soviet1_edcode4 dnat if year==1995 & edattain==1 [aw=weight],
outreg2 using "$dropbox/tables/Israel6_`tablenum'.xls", tex(frag) noaster replace  nonotes nor2 dec(3) fmt(f) drop(_I** dnat)  label nocons stats(coef se) addtext("Controls for own-native supply","yes") ctitle("$\Delta$ Nat. Wages","Edu. code 1","OLS")
xi: ivreg2 dwage2 soviet1_edcode4 dnat if year==1995 & edattain==2 [aw=weight], 
outreg2 using "$dropbox/tables/Israel6_`tablenum'.xls", tex(frag) noaster nonotes  nor2 dec(3) fmt(f) drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for own-native supply","yes") ctitle("$\Delta$ Nat. Wages","Edu. code 2","OLS")
xi: ivreg2 dwage2 soviet1_edcode4 dnat if year==1995 & edattain==3 [aw=weight], 
outreg2 using "$dropbox/tables/Israel6_`tablenum'.xls", tex(frag) noaster nonotes  nor2 dec(3) fmt(f) drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for own-native supply","yes") ctitle("$\Delta$ Nat. Wages","Edu. code 3","OLS")
xi: ivreg2 dwage2 soviet1_edcode4 dnat if year==1995 & edattain==4 [aw=weight], 
outreg2 using "$dropbox/tables/Israel6_`tablenum'.xls", tex(frag) noaster nonotes  nor2 dec(3) fmt(f) drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for own-native supply","yes") ctitle("$\Delta$ Nat. Wages","Edu. code 4","OLS")

xi: ivreg2 dwage2 (soviet1_edcode4 = soviet0_edcode4) dnat if year==1995 & edattain==1 [aw=weight],
outreg2 using "$dropbox/tables/Israel7_`tablenum'.xls", tex(frag) noaster replace nonotes nor2 dec(3) fmt(f) drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for own-native supply","yes") ctitle("$\Delta$ Nat. Wages","Edu. code 1","IV")
xi: ivreg2 dwage2 (soviet1_edcode4 = soviet0_edcode4) dnat if year==1995 & edattain==2 [aw=weight],
outreg2 using "$dropbox/tables/Israel7_`tablenum'.xls", tex(frag) noaster nonotes  nor2 dec(3) fmt(f) drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for own-native supply","yes") ctitle("$\Delta$ Nat. Wages","Edu. code 2","IV")
xi: ivreg2 dwage2 (soviet1_edcode4 = soviet0_edcode4) dnat if year==1995 & edattain==3 [aw=weight],
outreg2 using "$dropbox/tables/Israel7_`tablenum'.xls", tex(frag) noaster nonotes  nor2 dec(3) fmt(f) drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for own-native supply","yes") ctitle("$\Delta$ Nat. Wages","Edu. code 3","IV")
xi: ivreg2 dwage2 (soviet1_edcode4 = soviet0_edcode4) dnat if year==1995 & edattain==4 [aw=weight],
outreg2 using "$dropbox/tables/Israel7_`tablenum'.xls", tex(frag) noaster nonotes  nor2 dec(3) fmt(f) drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for own-native supply","yes") ctitle("$\Delta$ Nat. Wages","Edu. code 4","IV")
}

if ("`education'"=="aggregate") {

** GENERATE INTERACTIONS

gen edcode1=(edattain==1)
gen edcode2=(edattain==2)

local varlist "soviet1 soviet0"
foreach var of local varlist{
forvalues i=1(1)2 {
gen sign = abs(`var')/`var'
gen `var'_aux=`var'*edcode`i'
bysort `geo' year: egen `var'_edcode`i'=max(abs(`var'_aux))
replace `var'_edcode`i' = `var'_edcode`i' * sign if `var'!=0
drop `var'_aux sign
}
}

forvalues i=1(1)2 {
gen sign = abs(dnat)/dnat
gen dnat_aux=dnat*edcode`i'
bysort `geo' year: egen dnat_edcode`i'=max(abs(dnat_aux))
replace dnat_edcode`i' = sign * dnat_edcode`i'
drop dnat_aux sign
}
forvalues i=1(1)2 {
gen edcode`i'_soviet1_edcode1=edcode`i'*soviet1_edcode1
}


label var soviet1_edcode2 "Inflows from Soviet Union, most-skilled" 

xi: ivreg2 dwage2 soviet1_edcode2 dnat_edc** if year==1995 & edattain==1 [aw=weight],
outreg2 using "$dropbox/tables/Israel6_`tablenum'.xls", tex(frag) noaster replace  nonotes nor2 dec(3) fmt(f) drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Wages","Low-skilled","OLS")
xi: ivreg2 dwage2 soviet1_edcode2 dnat_edc** if year==1995 & edattain==2 [aw=weight], 
outreg2 using "$dropbox/tables/Israel6_`tablenum'.xls", tex(frag) noaster nonotes  nor2 dec(3) fmt(f) drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Wages","Univ. Degree","OLS")

xi: ivreg2 dwage2 (soviet1_edcode2 = soviet0_edcode2) dnat_edc** if year==1995 & edattain==1 [aw=weight],
outreg2 using "$dropbox/tables/Israel6_`tablenum'.xls", tex(frag) noaster  nonotes nor2 dec(3) fmt(f) drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Wages","Low-skilled","IV")
xi: ivreg2 dwage2 (soviet1_edcode2 = soviet0_edcode2) dnat_edc** if year==1995 & edattain==2 [aw=weight],
outreg2 using "$dropbox/tables/Israel6_`tablenum'.xls", tex(frag) noaster nonotes  nor2 dec(3) fmt(f) drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Wages","Univ. Degree","IV")

}

end


cap program drop sumstats //This program investigates the heteroneity of the effect across age groups
program define sumstats

syntax using/,  geo(string) [agemin(integer 1) agemax(integer 1)  sex(string) age(string) ]  

*** SUMMARY STATS TABLE

tempfile data t1 t2 t3 t4 t5 t6 t7

use "`using'", clear

keep if year==1995 


gen soviet_stock=0
replace soviet_stock=1 if bplcountry==34010 | bplcountry==34020 | bplcountry==41010 | bplcountry==42020 | ///
		    bplcountry==34050 | bplcountry==32060 | bplcountry==32070 | bplcountry== 42070 | ///
		    bplcountry==42080 | bplcountry==41060 | bplcountry==41080 | bplcountry==32120 | ///
		    bplcountry==32130 | bplcountry==32140 | bplcountry==41100 
gen soviet=0
replace soviet=1 if (bplcountry==34010 | bplcountry==34020 | bplcountry==41010 | bplcountry==42020 | ///
		    bplcountry==34050 | bplcountry==32060 | bplcountry==32070 | bplcountry== 42070 | ///
		    bplcountry==42080 | bplcountry==41060 | bplcountry==41080 | bplcountry==32120 | ///
		    bplcountry==32130 | bplcountry==32140 | bplcountry==41100) & (yrimm2==66 | yrimm2==72) 


generate native=(soviet_stock!=1)

gen active=(laboril==1)
gen inactive=(laboril==2)

generate native_active=(active==1 & native==1)
generate native_inactive=(inactive==1 & native==1)

save `data', replace

use `data', clear

gen soviet_col=perwt / 1000 if year==1995 & soviet==1
gen native_col=perwt / 1000 if year==1995 & native==1

collapse (sum) soviet_col native_col

gen shock_col = (soviet_col / native_col) * 100

gen varname="All persons (in 1000)"
save `t1', replace

use `data', clear

gen soviet_col=perwt / 1000 if year==1995 & soviet==1 & age>=25 & age<=59
gen native_col=perwt / 1000 if year==1995 & native==1 & age>=25 & age<=59

collapse (sum) soviet_col native_col

gen shock_col = (soviet_col / native_col) * 100

gen varname="Aged 25-59"
save `t2', replace

use `data', clear

gen soviet_col=perwt / 1000 if year==1995 & soviet==1 & age>=25 & age<=59 & sex==1
gen native_col=perwt / 1000 if year==1995 & native==1 & age>=25 & age<=59 & sex==1

collapse (sum) soviet_col native_col

gen shock_col = (soviet_col / native_col) * 100

gen varname="Male, Aged 25-59"
save `t3', replace

use `data', clear

gen soviet_col=1 if year==1995 & soviet==1 & age>=25 & age<=59 & sex==1
gen native_col=1 if year==1995 & native==1 & age>=25 & age<=59 & sex==1

collapse (sum) soviet_col native_col

gen shock_col = .

gen varname="Sample Size: Male, Aged 25-59"
save `t4', replace


use `data', clear

gen soviet_col=perwt if year==1995 & age>=25 & age<=59 & sex==1 & soviet==1
gen native_col=perwt if year==1995 & age>=25 & age<=59 & sex==1 & native==1

collapse (sum) soviet_col native_col, by(edattain) 

gen shock_col = soviet_col / native_col

drop if edattain==0 | edattain==9

local varlist "soviet_col native_col"
foreach var of local varlist{
egen tot_`var' = sum(`var')
replace `var' = `var' / tot_`var'
drop tot_`var'
}

sort edattain
gen varname="Less than primary"
replace varname="Primary completed" in 2
replace varname="Secondary completed" in 3
replace varname="University completed" in 4

replace soviet_col = soviet_col * 100
replace native_col = native_col * 100
replace shock_col = shock_col * 100

save `t5', replace

use `data', clear

gen soviet_col=perwt / 1000 if year==1995 & soviet==1 & age>=25 & age<=59 & sex==1 
gen native_col=perwt / 1000 if year==1995 & native==1 & age>=25 & age<=59 & sex==1 

collapse (sum) soviet_col native_col, by(occ)

drop if occ==98 | occ==99 //Non-employed workers in the 1985 sample have no occupation 

gen shock_col = soviet_col / native_col

egen tot_soviet=sum(soviet)
egen tot_native=sum(native)

replace soviet_col = soviet_col / tot_soviet
replace native_col = native_col / tot_native
drop tot_**

sort occ

gen varname="Academic professionals"
replace varname="Associate professionals and technicians" in 2
replace varname="Managers" in 3
replace varname="Clerical workers" in 4
replace varname="Agents, sales workers and service workers" in 5
replace varname="Skilled agricultural workers" in 6
replace varname="Skilled workers in industry, construction and other skilled workers" in 7
replace varname="Unskilled workers" in 8

drop occ

replace soviet_col = soviet_col * 100
replace native_col = native_col * 100
replace shock_col = shock_col * 100

save `t6', replace

use `data', clear

gen soviet_col=perwt / 1000 if year==1995 & soviet==1 & age>=25 & age<=59 & sex==1 
gen native_col=perwt / 1000 if year==1995 & native==1 & age>=25 & age<=59 & sex==1 

keep if edattain>=4

collapse (sum) soviet_col native_col, by(occ)

gen shock_col = soviet_col / native_col

drop if occ==98 | occ==99 //Non-employed workers in the 1985 sample have no occupation 

egen tot_soviet=sum(soviet)
egen tot_native=sum(native)

replace soviet_col = soviet_col / tot_soviet
replace native_col = native_col / tot_native
drop tot_**

sort occ

gen varname="Academic professionals"
replace varname="Associate professionals and technicians" in 2
replace varname="Managers" in 3
replace varname="Clerical workers" in 4
replace varname="Agents, sales workers and service workers" in 5
replace varname="Skilled agricultural workers" in 6
replace varname="Skilled workers in industry, construction and other skilled workers" in 7
replace varname="Unskilled workers" in 8

drop occ

replace soviet_col = soviet_col * 100
replace native_col = native_col * 100
replace shock_col = shock_col * 100

save `t7', replace


use `t1'
append using `t2'
append using `t3'
append using `t4'
append using `t5'
append using `t6'
append using `t7'

foreach var of varlist soviet_col native_col shock_col { 
	generate `var'_str = string(`var',"%6.1f") if varname!="Sample Size: Male, Aged 25-59"
	replace `var'_str = string(`var',"%6.0f") if varname=="Sample Size: Male, Aged 25-59"
	replace `var'_str = "" if `var'_str=="."
}
drop soviet_col native_col shock_col


gen order=_n
replace order=order+1 if order>4
set obs 27
replace order=5 in 25

replace varname="&&\\ Percent Male, Aged 25-59 with: & & & \\" in 25
replace order=order+1 if order>9
replace order=10 in 26
replace varname="&&\\ Percent Male, Aged 25-59 working as: & & &  \\" in 26

replace order=order+1 if order>18
replace order=19 in 27
replace varname="&&\\ Percent High-skilled, Male, Aged 25-59 working as: & & &  \\" in 27
sort order
drop order

listtex varname  soviet_col native_col shock_col using "$dropbox/tables/sumstat_Israel.tex", replace ///
rstyle(tabular) head("\begin{tabular}{lccc} \hline" " & Emigres from former Soviet Union & Israeli natives & Size of the shock \\ \hline") foot("\hline \end{tabular}")

keep varname  soviet_col native_col shock_col 
export excel using "$dropbox/tables/sumstat_Israel.xls", replace 

*** FIGURE BALANCE SHOCK

use "`using'", clear

keep if year==1995 | year==1983

** age selection

keep if age>=`agemin' & age<=`agemax'

** Drop females if sex==1

if ("`sex'"=="1") {
drop if sex==2
}


** Drop observations without occupation or industry information if occupation or industry cells
if ("`geo'"=="occ"){
**recode occupations. This part follows Borja's code
generate oldocc=occ
replace occ=0 if occ==1 & year<1995
replace occ=1 if occ==2 & year<1995
replace occ=2 if occ==3 & year<1995
replace occ=3 if occ==4 & year<1995
replace occ=4 if (occ==5 | occ==6) & year<1995
replace occ=5 if occ==7 & year<1995
replace occ=6 if occ==8 & year<1995
replace occ=7 if occ==9 & year<1995
drop if occ==98 | occ==99 //Non-employed workers in the 1985 sample have no occupation 
}
if ("`geo'"=="geo2") {
drop if geo2_ilx==.
}


gen soviet_stock=0
replace soviet_stock=1 if bplcountry==34010 | bplcountry==34020 | bplcountry==41010 | bplcountry==42020 | ///
		    bplcountry==34050 | bplcountry==32060 | bplcountry==32070 | bplcountry== 42070 | ///
		    bplcountry==42080 | bplcountry==41060 | bplcountry==41080 | bplcountry==32120 | ///
		    bplcountry==32130 | bplcountry==32140 | bplcountry==41100 
gen soviet=0
replace soviet=1 if (bplcountry==34010 | bplcountry==34020 | bplcountry==41010 | bplcountry==42020 | ///
		    bplcountry==34050 | bplcountry==32060 | bplcountry==32070 | bplcountry== 42070 | ///
		    bplcountry==42080 | bplcountry==41060 | bplcountry==41080 | bplcountry==32120 | ///
		    bplcountry==32130 | bplcountry==32140 | bplcountry==41100) & (yrimm2==66 | yrimm2==72) 


generate native=(soviet_stock!=1)

gen active=(laboril==1)
gen inactive=(laboril==2)

generate native_active=(active==1 & native==1)
generate native_inactive=(inactive==1 & native==1)

replace soviet_stock=soviet_stock*perwt
replace soviet=soviet*perwt
replace native=native*perwt 
generate byte agecode=1*(age>=25 & age<=34) + 2*(age>=35 & age<=44) + 3*(age>=45 & age<=54) + 4*(age>=55 & age<=59)

gen obs=1

** Selects the sample for the wages regressions. Drop not valid wage, keep salary worker, nonrussian, not in school and native 

replace incwage=. if incwage==9999999 | incwage==9999998 | incwage==0 | classwk!=2 | soviet==1 | school==1 
replace incwage=incwage/1000 if year==1983 // The old shekel moves to the new shekel
replace incwage=ln(incwage)

drop if edattain==9 //Education attainment not known. Alternatively we can recode this as lowest level.

collapse (rawsum) soviet soviet_stock native total=perwt native_active native_inactive (count) nobs=native (mean) incwage [aw=perwt], by(`geo' year edattain `age')

egen code=group(`geo'  edattain  `age')
tsset code year, delta(12)


*THIS GIVES THE CHANGE IN UNEMP & EMP RATE OF NON-REPATRIATE FRENCH NATIVES

generate dwage2=incwage - L.incwage
generate derate2=(native_active/native) - (L.native_active/L.native)

tsset code year, delta(12)


**************************
*BUT WHAT ABOUT THE OTHER GUEST WORKERS
*WE WILL NEED TO ADDRESS THIS ISSUE SOMEHOW
*FOR NOW I WILL IGNORE THEM
***************************

*WE WANT TO DEFINE THE SHOCKS IN TERMS OF THE CORRECT THEORETICAL SPECIFICATION

*IN TIME 0, EVERYONE IS A FRENCH NATIVE
*IN TIME 1, ONLY THE NON-ALGERIANS AND NON-REPATRIATES ARE "NATIVES"
*I WILL DEFINE THE NATIVE CHANGE IN TERMS OF POPULATION TO AVOID ENDOGENEITY
generate nat0=L.total
generate nat1=total-soviet
generate dnat=log(nat1/nat0)


*THE SUPPLY SHOCK IS # OF IMMIGRANTS DIVIDED BY "NATIVES" IN 1968
*DREP MEASURES THE NUBMER OF REPATRIATE IMMIGRANTS

generate dsoviet=soviet_stock-L.soviet_stock
generate soviet1=soviet/(total) //This is a change relative to the original code, some cells there are just too many soviets. 


*CREATING THE INSTRUMENTS
*JUST GET SHARE IN 1962 CELL RELATIVE TO EVERYONE

generate soviet0=L.soviet_stock/L.total

*NOBS IS THE NUMBER OF NATIVES, BOTH WORKING & NON-WORKING, IN CELL;
generate weight=(nobs*L.nobs)/(nobs+L.nobs)


*** Labeling variables

label var dwage2 "Wages"
label var derate2 "Share Employed"

label var soviet0 "L. Share from Soviet Union"

label var soviet1 "Inflows from Soviet Union"
label var dnat "Change in cell size"


local varlist "soviet total"
foreach var of local varlist{
replace `var'=0 if `var'==.
bysort year `geo' `age': egen tot_`var'=sum(`var')
gen share_`var'=`var'/tot_`var'
}

gen weight_soviet=tot_soviet/tot_total

local max=1 //0.05
gen unifrm=runiform()*`max'

two (scatter share_soviet share_total [aw=weight_soviet] if year==1995 &edattain==1 & share_soviet>=0 & share_soviet<=`max' & share_total>=0 & share_total<=`max', msymbol(circle_hollow) msize(vsmall)) ///
    (scatter share_soviet share_total [aw=weight_soviet] if year==1995 &edattain==2 & share_soviet>=0 & share_soviet<=`max' & share_total>=0 & share_total<=`max', msymbol(circle_hollow) msize(vsmall)) ///
    (scatter share_soviet share_total [aw=weight_soviet] if year==1995 &edattain==3 & share_soviet>=0 & share_soviet<=`max' & share_total>=0 & share_total<=`max', msymbol(circle_hollow) msize(vsmall)) ///
    (scatter share_soviet share_total [aw=weight_soviet] if year==1995 &edattain==4 & share_soviet>=0 & share_soviet<=`max' & share_total>=0 & share_total<=`max', msymbol(circle_hollow) msize(vsmall)) ///
    (lfit unifrm unifrm), ///
    graphregion(color(white)) ytitle("Share Soviet emigres")xtitle("Share natives")legend(off) ///
    yscale(range(0(0.2)1))xscale(range(0(0.2) 1))ylabel(0(.2)1)xlabel(0(.2)1) //yscale(range(0(0.01)0.05))xscale(range(0(0.01)0.05))ylabel(0(0.01)0.05)xlabel(0(0.01)0.05) 
    graph export "$dropbox/figures/distributions_new_soviet_`geo'.png", replace

end


cap program drop language_graph 
program define language_graph

syntax using/,  geo(string) [agemin(integer 1) agemax(integer 1)  sex(string) age(string) ]  

aggregate_data using "$dropbox/source/Israeli_raw_Census.dta", geo(`geo') sex(`sex') agemin(`agemin') agemax(`agemax') //age(agecode) 

xi: areg soviet1  `age' if year==1995 [aw=weight],robust a(edattain)
predict soviet1_res, res
xi: areg hebrew_lang0  `age' if year==1995 [aw=weight],robust a(edattain)
predict hebrew_lang0_res, res

two (scatter soviet1 hebrew_lang0 if edattain==1 [aw=weight], msymbol(circle_hollow) msize(vsmall)) ///
    (scatter soviet1 hebrew_lang0 if edattain==2 [aw=weight], msymbol(circle_hollow) msize(vsmall)) ///
    (scatter soviet1 hebrew_lang0 if edattain==3 [aw=weight], msymbol(circle_hollow) msize(vsmall)) ///
    (scatter soviet1 hebrew_lang0 if edattain==4 [aw=weight], msymbol(circle_hollow) msize(vsmall)) ///
    (lfit soviet1_res hebrew_lang0 [aw=weight]), ////
     legend(off) xtitle("Share of indivduals using Hebrew in 1983")ytitle("Soviet inflows in 1995") graphregion(color(white))
    graph export "$dropbox/figures/language_soviet_`geo'.png", replace

two (scatter soviet1_res hebrew_lang0_res if edattain==1 [aw=weight], msymbol(circle_hollow) msize(vsmall)) ///
    (scatter soviet1_res hebrew_lang0_res if edattain==2 [aw=weight], msymbol(circle_hollow) msize(vsmall)) ///
    (scatter soviet1_res hebrew_lang0_res if edattain==3 [aw=weight], msymbol(circle_hollow) msize(vsmall)) ///
    (scatter soviet1_res hebrew_lang0_res if edattain==4 [aw=weight], msymbol(circle_hollow) msize(vsmall)) ///
    (lfit soviet1_res hebrew_lang0_res [aw=weight]), ////
     legend(off) xtitle("Share of indivduals using Hebrew in 1983, normalized by education levels")ytitle("Soviet inflows in 1995, normalized by education levels") graphregion(color(white))
    graph export "$dropbox/figures/language_soviet_`geo'_res.png", replace


xi: areg soviet1 hebrew_lang0 `age' if year==1995 [aw=weight],robust a(edattain)
xi: areg soviet1_res hebrew_lang0_res `age' if year==1995 [aw=weight],robust a(edattain)

end



/***********************
** CALLS
***********************/

/***********************
** SUMMARY STATS AND GRAPHS OF DISTRIBUTION OF THE SHOCK
***********************/

sumstats using "$dropbox/source/Israeli_raw_Census.dta", agemin(25) agemax(59) sex(1) geo(geo2) //age(agecode) 
sumstat_dependent using "$dropbox/source/Israeli_raw_Census.dta", agemin(25) agemax(59) sex(1) //age(agecode) 

** OCCUPATION

** Male population age>25 & age<60

aggregate_data using "$dropbox/source/Israeli_raw_Census.dta", geo(occ) sex(1) agemin(25) agemax(59) //age(agecode) 
regressions, tablenum(occ_male) geo(occ) file_name(Israeli_estimation_data) //age(i.agecode)

aggregate_data using "$dropbox/source/Israeli_raw_Census.dta", geo(occ) sex(1) agemin(25) agemax(59)  //age(agecode) 
regressions_cross_effects, tablenum(occ_male) geo(occ)  //age(i.agecode)

*** Language graphs

language_graph using "$dropbox/source/Israeli_raw_Census.dta", agemin(25) agemax(59) sex(1) geo(occ)
language_graph using "$dropbox/source/Israeli_raw_Census.dta", agemin(25) agemax(59) sex(1) geo(geo2)


/* EXTRA CHECKS RAN

//aggregate_data using "$dropbox/source/Israeli_raw_Census.dta", geo(occ) sex(1) agemin(25) agemax(59) education(aggregate) //age(agecode) 
//regressions_cross_effects, tablenum(occ_male_agg) geo(occ) education(aggregate)  //age(i.agecode)


** GEOGRAPHY

** Male population age>25 & age<60

//aggregate_data using "$dropbox/source/Israeli_raw_Census.dta", geo(geo2) sex(1) agemin(25) agemax(59) //age(agecode) //Notes: with ENUTS1 and ENUTS2 the results are similar 
//regressions, tablenum(geo_male) geo(geo2) //age(i.agecode)


** GEO - OCCUPATION

** Male population age>25 & age<60

aggregate_data using "$dropbox/source/Israeli_raw_Census.dta", geo(occ) sex(1) agemin(25) agemax(59) age(geo2) 
regressions, tablenum(geo_occ_male) age(i.geo2)

